@@ -17,7 +17,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-/* $Id: fileio.c,v 1.35 2006/09/08 21:28:24 joerg_wunsch Exp $ */
+/* $Id: fileio.c,v 1.37 2007/01/24 22:43:46 joerg_wunsch Exp $ */
 
 #include "ac_cfg.h"
 
@@ -28,6 +28,7 @@
 #include <errno.h>
 #include <ctype.h>
 
+#include "avrdude.h"
 #include "avr.h"
 #include "fileio.h"
 
@@ -46,42 +47,38 @@ struct ihexrec {
 };
 
 
-extern char * progname;
-extern char   progbuf[];
-extern int    quell_progress;
-
-int b2ihex(unsigned char * inbuf, int bufsize, 
+static int b2ihex(unsigned char * inbuf, int bufsize, 
              int recsize, int startaddr,
              char * outfile, FILE * outf);
 
-int ihex2b(char * infile, FILE * inf,
+static int ihex2b(char * infile, FILE * inf,
              unsigned char * outbuf, int bufsize);
 
-int b2srec(unsigned char * inbuf, int bufsize, 
+static int b2srec(unsigned char * inbuf, int bufsize, 
            int recsize, int startaddr,
            char * outfile, FILE * outf);
 
-int srec2b(char * infile, FILE * inf,
+static int srec2b(char * infile, FILE * inf,
              unsigned char * outbuf, int bufsize);
 
-int ihex_readrec(struct ihexrec * ihex, char * rec);
+static int ihex_readrec(struct ihexrec * ihex, char * rec);
 
-int srec_readrec(struct ihexrec * srec, char * rec);            
+static int srec_readrec(struct ihexrec * srec, char * rec);
 
-int fileio_rbin(struct fioparms * fio,
+static int fileio_rbin(struct fioparms * fio,
                   char * filename, FILE * f, unsigned char * buf, int size);
 
-int fileio_ihex(struct fioparms * fio, 
+static int fileio_ihex(struct fioparms * fio, 
                   char * filename, FILE * f, unsigned char * buf, int size);
 
-int fileio_srec(struct fioparms * fio,
+static int fileio_srec(struct fioparms * fio,
                   char * filename, FILE * f, unsigned char * buf, int size);
 
-int fileio_num(struct fioparms * fio,
+static int fileio_num(struct fioparms * fio,
 		char * filename, FILE * f, unsigned char * buf, int size,
 		FILEFMT fmt);
 
-int fmt_autodetect(char * fname);
+static int fmt_autodetect(char * fname);
 
 
 
@@ -98,7 +95,7 @@ char * fmtstr(FILEFMT format)
 
 
 
-int b2ihex(unsigned char * inbuf, int bufsize, 
+static int b2ihex(unsigned char * inbuf, int bufsize, 
            int recsize, int startaddr,
            char * outfile, FILE * outf)
 {
@@ -176,7 +173,7 @@ int b2ihex(unsigned char * inbuf, int bufsize,
 }
 
 
-int ihex_readrec(struct ihexrec * ihex, char * rec)
+static int ihex_readrec(struct ihexrec * ihex, char * rec)
 {
   int i, j;
   char buf[8];
@@ -265,7 +262,7 @@ int ihex_readrec(struct ihexrec * ihex, char * rec)
  *
  * */
 
-int ihex2b(char * infile, FILE * inf,
+static int ihex2b(char * infile, FILE * inf,
              unsigned char * outbuf, int bufsize)
 {
   char buffer [ MAX_LINE_LEN ];
@@ -360,7 +357,7 @@ int ihex2b(char * infile, FILE * inf,
 }
 
 
-int b2srec(unsigned char * inbuf, int bufsize, 
+static int b2srec(unsigned char * inbuf, int bufsize, 
            int recsize, int startaddr,
            char * outfile, FILE * outf)
 {
@@ -466,7 +463,7 @@ int b2srec(unsigned char * inbuf, int bufsize,
 }
 
 
-int srec_readrec(struct ihexrec * srec, char * rec)
+static int srec_readrec(struct ihexrec * srec, char * rec)
 {
   int i, j;
   char buf[8];
@@ -542,7 +539,7 @@ int srec_readrec(struct ihexrec * srec, char * rec)
 }
 
 
-int srec2b(char * infile, FILE * inf,
+static int srec2b(char * infile, FILE * inf,
            unsigned char * outbuf, int bufsize)
 {
   char buffer [ MAX_LINE_LEN ];
@@ -702,7 +699,7 @@ static char *itoa_simple(int n, char *buf, int base)
 
 
 
-int fileio_rbin(struct fioparms * fio,
+static int fileio_rbin(struct fioparms * fio,
                   char * filename, FILE * f, unsigned char * buf, int size)
 {
   int rc;
@@ -732,7 +729,7 @@ int fileio_rbin(struct fioparms * fio,
 }
 
 
-int fileio_imm(struct fioparms * fio,
+static int fileio_imm(struct fioparms * fio,
                char * filename, FILE * f, unsigned char * buf, int size)
 {
   int rc = 0;
@@ -775,7 +772,7 @@ int fileio_imm(struct fioparms * fio,
 }
 
 
-int fileio_ihex(struct fioparms * fio, 
+static int fileio_ihex(struct fioparms * fio, 
                   char * filename, FILE * f, unsigned char * buf, int size)
 {
   int rc;
@@ -805,7 +802,7 @@ int fileio_ihex(struct fioparms * fio,
 }
 
 
-int fileio_srec(struct fioparms * fio,
+static int fileio_srec(struct fioparms * fio,
                   char * filename, FILE * f, unsigned char * buf, int size)
 {
   int rc;
@@ -836,7 +833,7 @@ int fileio_srec(struct fioparms * fio,
 }
 
 
-int fileio_num(struct fioparms * fio,
+static int fileio_num(struct fioparms * fio,
 	       char * filename, FILE * f, unsigned char * buf, int size,
 	       FILEFMT fmt)
 {
@@ -939,7 +936,7 @@ int fileio_setparms(int op, struct fioparms * fp)
 
 
 
-int fmt_autodetect(char * fname)
+static int fmt_autodetect(char * fname)
 {
   FILE * f;
   unsigned char buf[MAX_LINE_LEN];
